@ECHO OFF
REM C99C.BAT
REM
REM Batch file for x-compiling, optimizing and assembling
REM TI99/4A C99 programs
REM
REM Compiled code will be stored in the \OBJ directory
REM 
REM This batchfile is intended to be used with TotalCommander
REM  Command=		?:\Ti994w\Utl\C99c.bat
REM  Parameters=	%O %E or %N
REM     
REM  Iconfile=		?:\Ti994w\Utl\C99c.exe
REM  Tooltip=		C99C - Cross-compiler for the TI99/4A
REM
REM Author : Frederik G. Kaal
REM Version: 2.0
REM Date   : 02-01-2021
REM 
REM Call: C99C.BAT input_file_name (with extension)


@echo [%1] [%2] [%3] [%4] [%5]

SET SPACE=
SET PATH=D:\TI994W\UTL;%PATH%
SET VIEWER=d:\promite\utl\com\uedit\Uedit32.exe
IF NOT EXIST .\obj  mkdir .\obj

IF [%2]==[] goto V20
:V10
SET NAME=%1
SET EXT=.%2
GOTO :VXX

:V20
SET NAME=%~n1
SET EXT=%~x1
:VXX

REM ECHO [%NAME%]
REM ECHO [%EXT%]
REM PAUSE

if [%EXT%]==[.c99] goto compile
if [%EXT%]==[.C99] goto compile

if [%EXT%]==[.A99] goto assemble
if [%EXT%]==[.a99] goto assemble

COLOR CE
ECHO *** ERROR ***
start /WAIT wmessage -M%NAME%%EXT% does not have the right extension\nfor compiling like .C99\nor assembling like .A99 -TC99C -K1 -I4
goto end


:assemble
CD .\obj
SET ASRC=.\..\%NAME%%EXT%
goto XA99


:compile
@echo Start Compiling
if exist .\obj\%NAME%.err del .\obj\%NAME%.err
@echo C99C.EXE %NAME%%EXT% .\obj\%NAME%.a99
@echo on
C99C.EXE %NAME%%EXT% .\obj\%NAME%.a99 .\obj\%NAME%.err /t
@echo off
CD .\obj
findstring "No errors found" <%NAME%.err
if errorlevel 1 goto comperr
SET ASRC=%NAME%.s

@echo Start Optimizing
@echo C99O.EXE %NAME%.a99 %NAME%.o99
C99O.EXE %NAME%.a99 %NAME%.o99

@echo Start X-Optimizing
@echo C99X.EXE %NAME%.o99 %NAME%.x99
C99X.EXE %NAME%.o99 %NAME%.x99

@echo Start F-Optimizing
@echo C99F.EXE %NAME%.x99 %NAME%.f99
C99F.EXE %NAME%.x99 %NAME%.f99

@echo Start M-Optimizing
@echo C99M.EXE %NAME%.f99 %NAME%.s
C99M.EXE %NAME%.f99 %NAME%.s


:XA99
@echo Start Assembling
if exist %NAME%.aer del %NAME%.aer
@echo XA99.EXE -i%ASRC% -o%NAME%.x -l%NAME%.p -v -r -S -s %ASMOPT%
XA99.EXE -i%ASRC% -o%NAME%.x -l%NAME%.p -v -r -S -s %ASMOPT%
if errorlevel 1 goto asmerr
goto end

:comperr
@echo Compiler errors
start /WAIT wmessage -MCompiler errors -TC99 -K1 -I4
%VIEWER% %NAME%.ERR
set ERROR=1
goto end

:asmerr
@echo Assembler errors
start /WAIT wmessage -MAssembler errors -TXA99 -K1 -I4
REM %VIEWER% %NAME%.AER
%VIEWER% %NAME%.P
set ERROR=1
goto end

:end
cd ..
