TRACE OFF

#Command file interface
#======================
#Reading commands from a file and feed this into the emulator so that it is
#also possible to autostart basic programs etc.
#
#Commandline option: Ti994w.exe -cFilename.cmd
#
#Commands:
#
#   Name      | Description              | Example             | Explanation
#   ----------+--------------------------+---------------------+--------------------------------------------------
#   PAUSE     | Pause x ms               | PAUSE 10000         | pauses for 10 seconds
#   RESET     | Start with reset vector  | RESET               | resets the emulator
#   RUNONCE   | RunOnce on/off           | RUNONCE             | displays status of RUNONCE; ON or OFF
#             |                          | RUNONCE ON          | only when emulator is started
#             |                          | RUNONCE OFF         | executes script after every reset (default)
#   BREAK     | Break on/off             | BREAK               | displays status of BREAK; ON or OFF
#             |                          | BREAK   ON          | stop script when fctn-4 is pressed (default)
#             |                          | BREAK   OFF         | do not stop script when fctn-4 is pressed
#   TRACE     | Verbose on/off           | TRACE               | displays status of TRACE; ON or OFF
#             |                          | TRACE   ON          | prints every executed command in the debug window
#             |                          | TRACE   OFF         | do not print every executed command in the debug window (default)
#   PRINT     | Print a message          | PRINT "Hello world" | print a message in the debug window
#   REPEAT    | Repeat block n times     | REPEAT 3            | repeat all commands n times 
#   LOOP      | Do repeat loop           | LOOP                | end of repeat loop
#             |                          |                     |
#   :LABEL    | Define a label           | :MYLABEL            | define a label for a goto or gosub statement
#   GOTO      | Goto a label             | GOTO [:]MYLABEL     | continue command file at line after label
#   GOSUB     | Call a subroutine        | GOSUB [:]MYLABEL    | continue command file at line after label
#   RETURN    | Return from a subroutine | RETURN              | continue command file at line after last executed gosub call
#             |                          |                     |  
#   DSK       | Select DSK               | DSK "c:\thisdir"    | select a DSK directory
#   DSK1      | Select DSK1              | DSK1 "c:\dir\dsk1"  | select a DSK1 directory
#   DSK1      | Select DSK1              | DSK1 "c:\file.dsk"  | select a DSK1 DSK image
#   DSK2      | Select DSK2              | DSK2 "c:\dir\..."   | same as DSK1
#   DSK3      | Select DSK3              | DSK3 "c:\dir\..."   | same as DSK1
#   MODULE    | Select a module          | MODULE "ExtBasic"   | select a module, use the same name as defined in Ti994w.ini
#   SENDKEY   | Send normal keys         | SENDKEY "RUN\n"     | send normal keys a-z, A-Z, 0-9 etc, use \n for newline/enter
#   SENDCTRL  | Send control keys        | SENDCTRL "C"        | send key(s) with ctrl-key pressed (example ctrl-C)
#   SENDFCTN  | Send function keys       | SENDFCTN "4"        | send key(s) with fctn-key pressed (example fctn-4)
#   MAXIMIZE  | Maximize mainwindow      | MAXIMIZE            | maximize the emulator window
#   RESTORE   | Restore mainwindow       | RESTORE             | restore the emulator window
#   MINIMIZE  | Minimize mainwindow      | MINIMIZE            | minimize the emulator window
#   EXIT      | Exit emulator            | EXIT                | exit the emulator
#   END       | End of command file      | END                 | end the execution of the command file
#
#[EOF]

#No SCRIPT
#GOTO :Test1
#GOTO :Test2
END



:Test1
#MAXIMIZE
TRACE ON
RUNONCE ON
BREAK OFF
TRACE
RUNONCE
BREAK
END

:Test2
PRINT "RUN A TI-BASIC PROGRAM"
MAXIMIZE
SENDKEY " 1"
PAUSE 500
SENDKEY "OLD DSK1.MYPROGRAM\n"
SENDKEY "RUN\n"
END
